diff test/runtime/NMT/CommandLineSummary.java @ 14909:4ca6dc0799b6

Backout jdk9 merge
author Gilles Duboscq <duboscq@ssw.jku.at>
date Tue, 01 Apr 2014 13:57:07 +0200
parents 21db9a1d43ef
children 52b4284cb496
line wrap: on
line diff
--- a/test/runtime/NMT/CommandLineSummary.java	Tue Apr 01 14:09:03 2014 +0200
+++ b/test/runtime/NMT/CommandLineSummary.java	Tue Apr 01 13:57:07 2014 +0200
@@ -24,7 +24,7 @@
  /*
  * @test
  * @key nmt
  * @summary Running with NMT summary should not result in an error
  * @library /testlibrary
  */
 
@@ -39,6 +39,7 @@
       "-version");
     OutputAnalyzer output = new OutputAnalyzer(pb.start());
     output.shouldNotContain("error");
+    output.shouldNotContain("warning");
     output.shouldHaveExitValue(0);
   }
 }
@@ -24,7 +24,7 @@
  * @test
  * @key nmt
- * @summary Running with NMT summary should not result in an error
+ * @summary Running with NMT summary should not result in an error or warning
  * @library /testlibrary
  */